#!/bin/bash

# Explanation: I build the full TeX Live binary folder and submit these files to Karl.
#     His script initially installs the full collection in the pretest distribution.
#     But after the initial install, it does a byte-for-byte comparison of each new
#     binary with the existing binary using "cmp", and only installs binaries that
#     have changed. During the pretest, users frequently update; the mechanism
#     for updating only installs changed files. Thus updaters only have to download
#     and install three or four changed binaries rather than the full set of 450.
#
#     Unhappily, the lipo mechanism apparently inserts either dates or garbage bytes.
#     Consequently if we have old files: a-Arm, a-Intel, a-Universal, and new files:
#     a1-Arm, a1-Intel, a1-Universal, and if a-Arm and a1-Arm are bytewise equal
#     and a-Intel and a1-Intel are bytewise equal, usually a-Universal and a1-Universal
#     are different.
#
#     Consequently, a more elaborate scheme is needed to update pretest binaries
#     after the initial submission. The elaborate scheme works like this: we keep
#     dated folders each time we make binaries; a dated folder has a name like
#     RawCode/2021-Pretest-March-4.  This folder contains aarch64-apple-darwin
#     and x86_64-apple-darwin and asy-Arm and asy-Intel, that is, the raw binaries
#     compiled on the given date. It also contains universal-darwin, the full set of
#     lipoed and signed binaries that are submitted to the pretest on that date. This
#     set includes asy.
#
#     Scripts actually construct this universal-darwin on the spot as follows:
#
#     A list is constructed of all x86_64-darwin new files. For each actual binary in this list, the
#     corresponding binary in the previous copy of x86_64-darwin is byte-wise compared to it.
#     If the two files are different, then the corresponding new binary in aarch64-apple-darwin
#     is found and lipoed to the new binary in x86_64-apple-darwin, the universal binary is signed,
#     and it is placed in the new universal-darwin. But if the new and old x86_64 binaries are
#     bytewise equal, the old universal from that folder's universal-darwin is copied to the new
#     universal-darwin. The same process is applied to asy-Intel. 
#
#     The list of new binaries is searched twice more, once for scripts and once for links. But this
#      time we avoid comparison and lipo and signing and just copy these straight over to the
#      new universal-darwin.
#
#      There is one special case. Suppose we are at the start of the pretest era, and creating our first
#      universal-darwin. Then all of this comparison is irrelevant. But we still need to store a copy of
#      the submitted universal-darwin in the RawCode/2021-Pretest-March-4 folder. This simple script does that.
#      So for the first submission, the scripts in Binary-2021 do the lipo and sign steps and create universal-darwin
#      in that folder. This script copies that universal-darwin into the appropriate RawCode folder.  




export COPYFILE_DISABLE=true


if [[ -d RawCode/2021-New/universal-darwin ]]; then
	rm -R RawCode/2021-New/universal-darwin
fi

mkdir RawCode/2021-New/universal-darwin

cd universal-darwin
files=`ls`
for f in $files; do
	if  ! [[ -L $f ]]; then
		cp $f ../RawCode/2021-New/universal-darwin/$f
	fi
done

for f in $files; do
	if   [[ -L $f ]]; then
		cp -R $f ../RawCode/2021-New/universal-darwin/$f
	fi
done






